@@ -3,6 +3,7 @@ import collections
 from bson.json_util import dumps, loads
 from tavi.errors import Errors
 from tavi.base.fields import BaseField
+import tavi
 
 def get_field_attr(cls, field):
     """Custom function for retrieving a tavi.field attribute. Handles nested
@@ -17,6 +18,14 @@ def get_field_attr(cls, field):
     else:
         return value
 
+def set_field_attr(cls, field, value):
+    """Custom function for setting a tavi.field attribute."""
+    field_descriptor = cls._field_descriptors[field]
+    if not value: value = field_descriptor.default
+    if isinstance(field_descriptor , tavi.fields.EmbeddedField) and not value: value = {}
+    if isinstance(value, dict): value = field_descriptor.doc_class(**value)
+    setattr(cls, field, value)
+
 class BaseDocumentMetaClass(type):
     """MetaClass for BaseDocuments. Handles initializing the list of fields for
     the BaseDocument.
@@ -31,8 +40,7 @@ class BaseDocumentMetaClass(type):
             key = lambda i: i[1].creation_order
         )
 
-        cls._fields = [name for name, _ in sorted_fields]
-        cls._field_descriptors = dict(sorted_fields)
+        cls._field_descriptors = collections.OrderedDict(sorted_fields)
 
 class BaseDocument(object):
     """Base class for Mongo Documents. Provides basic field support."""
@@ -42,9 +50,7 @@ class BaseDocument(object):
         self._errors = Errors()
         for field in self.fields:
             field_descriptor = self._field_descriptors[field]
-            field_default = field_descriptor.default
-
-            field_descriptor.setFieldOnObject(self, kwargs.get(field))
+            set_field_attr(self, field, kwargs.get(field))
 
             field_value = getattr(self, field)
             if hasattr(field_value, "owner"):
@@ -66,7 +72,7 @@ class BaseDocument(object):
     @property
     def fields(self):
         """Returns the list of fields for the Document."""
-        return self._fields
+        return self._field_descriptors.keys()
 
     @property
     def valid(self):
