@@ -177,15 +177,8 @@ class EmbeddedField(BaseField):
     is not a tavi.document.EmbeddedDocument.
 
     """
-
-    def setFieldOnObject(self, obj, value):
-        if not value: value = {}
-        if value.__class__ != self.doc_class:
-           value = self.doc_class(**value)
-        super(EmbeddedField, self).setFieldOnObject(obj, value)
-
-    def __init__(self, name, doc):
-        super(EmbeddedField, self).__init__(name)
+    def __init__(self, name, doc, **kwargs):
+        super(EmbeddedField, self).__init__(name, **kwargs)
         doc_instance = doc()
 
         if not isinstance(doc_instance, EmbeddedDocument):
@@ -196,16 +189,19 @@ class EmbeddedField(BaseField):
                     )
 
         self.doc_class = doc
-        self.value = doc_instance
+        self.value = self.default or doc_instance
 
     def __get__(self, instance, owner):
         return self.value
 
     def __set__(self, instance, value):
         if value:
+            if not self.value: self.value = self.doc_class()
             for field in value.fields:
                 embedded_value = getattr(value, field, None)
                 setattr(self.value, field, embedded_value)
+        else:
+            self.value = value
 
 
 class ListField(BaseField):
